==> mingw-w64-arrow-14.0.2-1.src.tar.zst: apache-arrow-14.0.2/matlab/src/cpp/arrow/matlab/buffer/proxy/buffer.h <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#pragma once

#include "arrow/buffer.h"

#include "libmexclass/proxy/Proxy.h"

namespace arrow::matlab::buffer::proxy {

class Buffer : public libmexclass::proxy::Proxy {
    public:
        Buffer(std::shared_ptr<arrow::Buffer> buffer);
    
        ~Buffer() {}

        std::shared_ptr<arrow::Buffer> unwrap();

        static libmexclass::proxy::MakeResult make(const libmexclass::proxy::FunctionArguments& constructor_arguments);

    protected:
        void getNumBytes(libmexclass::proxy::method::Context& context);

        void toMATLAB(libmexclass::proxy::method::Context& context);

        void isEqual(libmexclass::proxy::method::Context& context);

        std::shared_ptr<arrow::Buffer> buffer;
};

}

==> mingw-w64-arrow-18.1.0-3.src.tar.zst: apache-arrow-18.1.0/matlab/src/cpp/arrow/matlab/buffer/proxy/buffer.h <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#pragma once

#include "arrow/buffer.h"

#include "libmexclass/proxy/Proxy.h"

namespace arrow::matlab::buffer::proxy {

class Buffer : public libmexclass::proxy::Proxy {
 public:
  Buffer(std::shared_ptr<arrow::Buffer> buffer);

  ~Buffer() {}

  std::shared_ptr<arrow::Buffer> unwrap();

  static libmexclass::proxy::MakeResult make(
      const libmexclass::proxy::FunctionArguments& constructor_arguments);

 protected:
  void getNumBytes(libmexclass::proxy::method::Context& context);

  void toMATLAB(libmexclass::proxy::method::Context& context);

  void isEqual(libmexclass::proxy::method::Context& context);

  std::shared_ptr<arrow::Buffer> buffer;
};

}  // namespace arrow::matlab::buffer::proxy
